void saveConfigCallback () {
  Serial.println("Should save config");
  shouldSaveConfig = true;
}

boolean WiFiConnection() {

  if (resetFlag) {
    WiFiManager wifiManager;
    wifiManager.resetSettings();
    // The extra parameters to be configured (can be either global or just in the setup)
    // After connecting, parameter.getValue() will get you the configured value
    // id/name placeholder/prompt default length
    WiFiManagerParameter customTokenKey("Push Safer Private Key", " Key From Push Safer", tokenKey, 100);
    WiFiManagerParameter customtrigBoardName("trigBoardName", "Unique Name", trigBoardName, 40);
    WiFiManagerParameter customTriggerMessage("TriggerMessage", "Trigger Message to be Sent", triggerMessage, 100);

    //set config save notify callback
    wifiManager.setSaveConfigCallback(saveConfigCallback);

    //add all your parameters here
    wifiManager.addParameter(&customTokenKey);
    wifiManager.addParameter(&customtrigBoardName);
    wifiManager.addParameter(&customTriggerMessage);

    wifiManager.setTimeout(120);
    if (!wifiManager.startConfigPortal("trigBoard")) {
      Serial.println("failed");
      return (0);
    } else {
      //if you get here you have connected to the WiFi
      Serial.println("WiFi connected");
      Serial.println(WiFi.SSID());
      Serial.println("IP address: ");
      Serial.println(WiFi.localIP());
    }
    //read updated parameters
    strcpy(tokenKey, customTokenKey.getValue());
    strcpy(trigBoardName, customtrigBoardName.getValue());
    strcpy(triggerMessage, customTriggerMessage.getValue());

    //save the custom parameters to FS
    if (shouldSaveConfig) {
      Serial.println("saving config");
      DynamicJsonBuffer jsonBuffer;
      JsonObject& json = jsonBuffer.createObject();
      json["tokenKey"] = tokenKey;
      json["trigBoardName"] = trigBoardName;
      json["triggerMessage"] = triggerMessage;

      File configFile = SPIFFS.open("/config.json", "w");
      if (!configFile) {
        Serial.println("failed to open config file for writing");
        return 0;
      }

      json.printTo(Serial);
      json.printTo(configFile);
      configFile.close();
      //end save
    }
    for (int i = 0; i < 100; i++) {
      digitalWrite(LEDpin, !digitalRead(LEDpin));
      delay(50);
    }
    return 1;
  }
  else {
    Serial.println("attemptig to connect");
    WiFi.mode(WIFI_STA);
    unsigned long startedAt = millis();
    WiFi.begin();
    while (WiFi.status() != WL_CONNECTED) {
      if (millis() - startedAt > 5000)// not there after 5 seconds, let's kill it
        return (0);
      yield();
    }
    Serial.println("");// WiFi info
    Serial.println("WiFi connected");
    Serial.println(WiFi.SSID());
    Serial.println("IP address: ");
    Serial.println(WiFi.localIP());
    Serial.println("Connected");
    return 1;
  }



}
